@@ -38,7 +38,7 @@ setMethod('cover', signature(x='SpatialPolygons', y='SpatialPolygons'),
 			}
 			y@proj4string <- x@proj4string
 		}	
-		subs <- gIntersects(x, y, byid=TRUE)
+		subs <- rgeos::gIntersects(x, y, byid=TRUE)
 		if (!any(subs)) {
 			next
 		} else {
@@ -66,13 +66,13 @@ setMethod('cover', signature(x='SpatialPolygons', y='SpatialPolygons'),
 			y@proj4string <- x@proj4string
 		}	
 		
-		i <- gIntersects(x, y)
+		i <- rgeos::gIntersects(x, y)
 		if (!i) {
 			next
 		}
 	
-		x <- spChFIDs(x, as.character(1:length(row.names(x))))
-		y <- spChFIDs(y, as.character(1:length(row.names(y))))
+		x <- spChFIDs(x, as.character(1:length(x)))
+		y <- spChFIDs(y, as.character(1:length(y)))
 
 		if (.hasSlot(x, 'data')) {
 			xnames <- colnames(x@data)
@@ -97,18 +97,18 @@ setMethod('cover', signature(x='SpatialPolygons', y='SpatialPolygons'),
 			doAtt <- FALSE
 		}
 		
-		subs <- gIntersects(x, y, byid=TRUE)
+		subs <- rgeos::gIntersects(x, y, byid=TRUE)
 		subsx <- apply(subs, 2, any)
 		subsy <- apply(subs, 1, any)
 	
-		int  <- gIntersection(x[subsx,], y[subsy,], byid=TRUE)
-		if (inherits(int, "SpatialCollections")) {
-			if (is.null(int@polyobj)) { # ??
-				warning('polygons do not intersect')
-				next
-			}
-			int <- int@polyobj
-		}
+		int  <- rgeos::gIntersection(x[subsx,], y[subsy,], byid=TRUE, drop_not_poly=TRUE)
+		#if (inherits(int, "SpatialCollections")) {
+		#	if (is.null(int@polyobj)) { # ??
+		#		warning('polygons do not intersect')
+		#		next
+		#	}
+		#	int <- int@polyobj
+		#}
 		if (!inherits(int, 'SpatialPolygons')) {
 			warning('polygons do not intersect')
 			next
