@@ -12,9 +12,9 @@
 	if( (!overwrite) & file.exists(filename)) {
 		stop('file exists; use overwrite=TRUE to overwrite it')
 	}
-	if (.couldBeLonLat(object)) { longlat=TRUE } else { longlat=FALSE }
+	if (couldBeLonLat(object)) { longlat=TRUE } else { longlat=FALSE }
 
-	e <- raster::edge(object, classes=FALSE, type='inner', asNA=TRUE) 
+	e <- boundaries(object, classes=FALSE, type='inner', asNA=TRUE) 
 	
 	r <- raster(object)
 	tr <- blockSize(r, n=3)
