@@ -41,12 +41,16 @@
 	btorder <- as.integer(r@file@byteorder != 'little')  # little -> 0, big -> 1
 	cat("byte order = ", btorder, "\n",file = thefile)		
 
-	if (.couldBeLonLat(r)) {
+	if (couldBeLonLat(r)) {
 		cat("map info = {Geographic Lat/Lon, 1, 1,", xmin(r),", ", ymax(r),", ", xres(r),", ", yres(r), "}\n", file = thefile)
 	} else {
 		cat("map info = {projection, 1, 1,", xmin(r),", ", ymax(r),", ", xres(r),", ", yres(r), "}\n", file = thefile)
 	}
-    cat("projection info =", projection(r), "\n", file = thefile) 
+	if (.requireRgdal(FALSE)) {
+		cat("coordinate system string = {", rgdal::showWKT(projection(r)), "}\n", file = thefile, sep="")
+	} else {
+		cat("projection info =", projection(r), "\n", file = thefile) 
+	}
 	cat("z plot range = {", minValue(r),", ", maxValue(r), "}\n", file = thefile) 
 	close(thefile)	
 }
