@@ -13,8 +13,8 @@
 		on.exit( ncdf4::nc_close(nc) )		
 		
 	} else {
-		nc <- open.ncdf(filename)
-		on.exit( close.ncdf(nc) )		
+		nc <- ncdf::open.ncdf(filename)
+		on.exit( ncdf::close.ncdf(nc) )		
 	} 
 
 	zvar <- .varName(nc, varname)
@@ -28,30 +28,30 @@
 		warning(zvar, ' has ', dims, ' dimensions, I am using the last one')
 	} else if (dims == 2) {
 		return( stack ( raster(filename, varname=zvar )  )  )
-	} else {
-		if (is.null(bands)) { bands <- ''}
-		if (bands[1] == '') {
-			bands = 1 : nc$var[[zvar]]$dim[[dim3]]$len
-		}
-		r <- raster(filename, varname=zvar, band=bands[1])
-		st <- stack( r )
-		st@title <- names(r)
-
-		if (length(bands) > 1) {
-			st@z <- list( nc$var[[zvar]]$dim[[dim3]]$vals[bands] )
-			names(st@z) <- nc$var[[zvar]]$dim[[dim3]]$units
-			if ( nc$var[[zvar]]$dim[[dim3]]$name == 'time' ) {	
-				try( st <- .doTime(st, nc, zvar, dim3, ncdf4)  )
-			}
-			nms <- as.character(st@z[[1]])
-			st@layers <- lapply(bands, function(x){
-												r@data@band <- x;
-												r@data@names <- nms[x];
-												return(r)} 
-											)
-		} 
-		return( st )
+	} 
+	
+	if (is.null(bands)) { bands <- ''}
+	if (bands[1] == '') {
+		bands = 1 : nc$var[[zvar]]$dim[[dim3]]$len
 	}
+	r <- raster(filename, varname=zvar, band=bands[1])
+	st <- stack( r )
+	st@title <- names(r)
+
+	if (length(bands) > 1) {
+		st@z <- list( nc$var[[zvar]]$dim[[dim3]]$vals[bands] )
+		names(st@z) <- nc$var[[zvar]]$dim[[dim3]]$units
+		if ( nc$var[[zvar]]$dim[[dim3]]$name == 'time' ) {	
+			try( st <- .doTime(st, nc, zvar, dim3, ncdf4)  )
+		}
+		nms <- as.character(st@z[[1]])
+		st@layers <- lapply(bands, function(x){
+											r@data@band <- x;
+											r@data@names <- nms[x];
+											return(r)} 
+										)
+	} 
+	return( st )
 }
 	
  #s = .stackCDF(f, varname='uwnd')
