@@ -21,7 +21,7 @@
 	datatype <- .getNetCDFDType(datatype)
 	nl <- nlayers(x)
 	
-	if (.couldBeLonLat(x)) {
+	if (couldBeLonLat(x)) {
 		if (missing(xname)) xname = 'longitude'
 		if (missing(yname)) yname = 'latitude'
 		xunit = 'degrees_east'
@@ -74,9 +74,9 @@
 
 			zdim <- ncdf4::ncdim_def( zname, zunit, zv, unlim=TRUE )
 			vardef <- ncdf4::ncvar_def( varname, varunit, list(xdim,ydim,zdim), NAvalue(x), prec = datatype )
-			#vardef <- var.def.ncdf( varname, varunit, list(xdim,ydim,zdim), -3.4e+38 )
+			#vardef <- ncdf::var.def.ncdf( varname, varunit, list(xdim,ydim,zdim), -3.4e+38 )
 		} else {
-			#vardef <- var.def.ncdf( varname, varunit, list(xdim,ydim), -3.4e+38 )
+			#vardef <- ncdf::var.def.ncdf( varname, varunit, list(xdim,ydim), -3.4e+38 )
 			vardef <- ncdf4::ncvar_def( varname, varunit, list(xdim,ydim), NAvalue(x), prec = datatype )
 		}
 		nc <- ncdf4::nc_create(filename, vardef)
@@ -126,8 +126,8 @@
 		
 	} else {  # library(ncdf)
 	
-		xdim <- dim.def.ncdf( xname, xunit, xFromCol(x, 1:ncol(x)) )
-		ydim <- dim.def.ncdf( yname, yunit, yFromRow(x, 1:nrow(x)) )
+		xdim <- ncdf::dim.def.ncdf( xname, xunit, xFromCol(x, 1:ncol(x)) )
+		ydim <- ncdf::dim.def.ncdf( yname, yunit, yFromRow(x, 1:nrow(x)) )
 		if (inherits(x, 'RasterBrick')) {
 
 			zv <- 1:nl
@@ -145,19 +145,19 @@
 				}
 			}
 
-			zdim <- dim.def.ncdf( zname, zunit, zv, unlim=TRUE )
-			vardef <- var.def.ncdf( varname, varunit, list(xdim,ydim,zdim), NAvalue(x), prec = datatype )
-			#vardef <- var.def.ncdf( varname, varunit, list(xdim,ydim,zdim), -3.4e+38 )
+			zdim <- ncdf::dim.def.ncdf( zname, zunit, zv, unlim=TRUE )
+			vardef <- ncdf::var.def.ncdf( varname, varunit, list(xdim,ydim,zdim), NAvalue(x), prec = datatype )
+			#vardef <- ncdf::var.def.ncdf( varname, varunit, list(xdim,ydim,zdim), -3.4e+38 )
 		} else {
-			#vardef <- var.def.ncdf( varname, varunit, list(xdim,ydim), -3.4e+38 )
-			vardef <- var.def.ncdf( varname, varunit, list(xdim,ydim), NAvalue(x), prec = datatype )
+			#vardef <- ncdf::var.def.ncdf( varname, varunit, list(xdim,ydim), -3.4e+38 )
+			vardef <- ncdf::var.def.ncdf( varname, varunit, list(xdim,ydim), NAvalue(x), prec = datatype )
 		}
-		nc <- create.ncdf(filename, vardef)
+		nc <- ncdf::create.ncdf(filename, vardef)
 
 		if (! missing(zatt)){
 			for (i in 1:length(zatt)) {
 				a <- trim(unlist(strsplit(zatt[i], '=')))
-				att.put.ncdf(nc, zname, a[1], a[2])	
+				ncdf::att.put.ncdf(nc, zname, a[1], a[2])	
 			}
 		}
 
@@ -165,37 +165,37 @@
 			x@file@nodatavalue <- NAflag
 		} 
 		
-		att.put.ncdf(nc, varname, '_FillValue', x@file@nodatavalue)
-		att.put.ncdf(nc, varname, 'missing_value', x@file@nodatavalue)
-		att.put.ncdf(nc, varname, 'long_name', longname)
+		ncdf::att.put.ncdf(nc, varname, '_FillValue', x@file@nodatavalue)
+		ncdf::att.put.ncdf(nc, varname, 'missing_value', x@file@nodatavalue)
+		ncdf::att.put.ncdf(nc, varname, 'long_name', longname)
 
 		proj <- projection(x) 
 		if (! is.na(proj)) { 
-			att.put.ncdf(nc, varname, 'projection', proj)
-			att.put.ncdf(nc, varname, 'projection_format', 'PROJ.4')
+			ncdf::att.put.ncdf(nc, varname, 'projection', proj)
+			ncdf::att.put.ncdf(nc, varname, 'projection_format', 'PROJ.4')
 		}
 
 		if (! missing(varatt)){
 			for (i in 1:length(varatt)) {
 				a <- trim(unlist(strsplit(varatt[i], '=')))
-				att.put.ncdf(nc, varname, a[1], a[2])	
+				ncdf::att.put.ncdf(nc, varname, a[1], a[2])	
 			}
 		}
 
-		att.put.ncdf(nc, 0, 'Conventions', 'CF-1.4')
+		ncdf::att.put.ncdf(nc, 0, 'Conventions', 'CF-1.4')
 		if (! missing(att)){
 			for (i in 1:length(att)) {
 				a <- trim(unlist(strsplit(att[i], '=')))
-				att.put.ncdf(nc, 0, a[1], a[2])	
+				ncdf::att.put.ncdf(nc, 0, a[1], a[2])	
 			}
 		}
 
 		
 		pkgversion = drop(read.dcf(file=system.file("DESCRIPTION", package='raster'), fields=c("Version")))
-		att.put.ncdf(nc, 0, 'created_by', paste('R, packages ncdf and raster (version ', pkgversion, ')', sep=''))
-		att.put.ncdf(nc, 0, 'date', format(Sys.time(), "%Y-%m-%d %H:%M:%S"))
+		ncdf::att.put.ncdf(nc, 0, 'created_by', paste('R, packages ncdf and raster (version ', pkgversion, ')', sep=''))
+		ncdf::att.put.ncdf(nc, 0, 'date', format(Sys.time(), "%Y-%m-%d %H:%M:%S"))
 
-		close.ncdf(nc)
+		ncdf::close.ncdf(nc)
 	}
 	
 	x@data@min <- rep(Inf, nl)
@@ -215,10 +215,10 @@
 		ncdf4::ncatt_put(nc, x@title, 'min', as.numeric(x@data@min))
 		ncdf4::ncatt_put(nc, x@title, 'max', as.numeric(x@data@max))
 	} else {
-		nc <- open.ncdf(x@file@name, write=TRUE)
-		on.exit( close.ncdf(nc) )
-		att.put.ncdf(nc, x@title, 'min', as.numeric(x@data@min))
-		att.put.ncdf(nc, x@title, 'max', as.numeric(x@data@max))
+		nc <- ncdf::open.ncdf(x@file@name, write=TRUE)
+		on.exit( ncdf::close.ncdf(nc) )
+		ncdf::att.put.ncdf(nc, x@title, 'min', as.numeric(x@data@min))
+		ncdf::att.put.ncdf(nc, x@title, 'max', as.numeric(x@data@max))
 	}
 
 	if (inherits(x, 'RasterBrick')) {
@@ -248,9 +248,9 @@
 		on.exit( ncdf4::nc_close(nc) )
 		try ( ncdf4::ncvar_put(nc, x@title, v, start=c(1, start), count=c(x@ncols, nr)) )
 	} else {
-		nc <- open.ncdf(x@file@name, write=TRUE)
-		try ( put.var.ncdf(nc, x@title, v, start=c(1, start), count=c(x@ncols, nr)) )
-		close.ncdf(nc)
+		nc <- ncdf::open.ncdf(x@file@name, write=TRUE)
+		try ( ncdf::put.var.ncdf(nc, x@title, v, start=c(1, start), count=c(x@ncols, nr)) )
+		ncdf::close.ncdf(nc)
 	}
 	return(x)
 }
@@ -295,9 +295,9 @@
 		on.exit( ncdf4::nc_close(nc) )
 		try ( ncdf4::ncvar_put(nc, x@title, v, start=c(1, start, lstart), count=c(ncols, rows, lend) ) )
 	} else {
-		nc <- open.ncdf(x@file@name, write=TRUE)
-		try ( put.var.ncdf(nc, x@title, v, start=c(1, start, lstart), count=c(ncols, rows, lend) ) )
-		close.ncdf(nc)
+		nc <- ncdf::open.ncdf(x@file@name, write=TRUE)
+		try ( ncdf::put.var.ncdf(nc, x@title, v, start=c(1, start, lstart), count=c(ncols, rows, lend) ) )
+		ncdf::close.ncdf(nc)
 	}
 	
 	return(x)
